nbqol.env.detect
================

.. automodule:: nbqol.env.detect

   
   .. rubric:: Functions

   .. autosummary::
   
      is_running_in_jupyter
      is_running_in_vscode
      is_running_in_vscode_jupyter
   